@@ -9,11 +9,11 @@ class TestSortQuery(TestCase):
         sorted_query = sort_query(query, '')
         assert query == sorted_query
 
-    def test_sort_by_column_ascending(self):
+    def test_column_ascending(self):
         query = sort_query(self.session.query(self.Article), 'name')
         assert 'ORDER BY article.name ASC' in str(query)
 
-    def test_sort_by_column_descending(self):
+    def test_column_descending(self):
         query = sort_query(self.session.query(self.Article), '-name')
         assert 'ORDER BY article.name DESC' in str(query)
 
@@ -22,21 +22,21 @@ class TestSortQuery(TestCase):
         sorted_query = sort_query(query, '-unknown')
         assert query == sorted_query
 
-    def test_sort_by_calculated_value_ascending(self):
+    def test_calculated_value_ascending(self):
         query = self.session.query(
             self.Category, sa.func.count(self.Article.id).label('articles')
         )
         query = sort_query(query, 'articles')
         assert 'ORDER BY articles ASC' in str(query)
 
-    def test_sort_by_calculated_value_descending(self):
+    def test_calculated_value_descending(self):
         query = self.session.query(
             self.Category, sa.func.count(self.Article.id).label('articles')
         )
         query = sort_query(query, '-articles')
         assert 'ORDER BY articles DESC' in str(query)
 
-    def test_sort_by_subqueried_scalar(self):
+    def test_subqueried_scalar(self):
         article_count = (
             sa.sql.select(
                 [sa.func.count(self.Article.id)],
@@ -52,7 +52,7 @@ class TestSortQuery(TestCase):
         query = sort_query(query, '-articles')
         assert 'ORDER BY articles DESC' in str(query)
 
-    def test_sort_by_aliased_joined_entity(self):
+    def test_aliased_joined_entity(self):
         alias = sa.orm.aliased(self.Category, name='categories')
         query = self.session.query(
             self.Article
@@ -62,17 +62,17 @@ class TestSortQuery(TestCase):
         query = sort_query(query, '-categories-name')
         assert 'ORDER BY categories.name DESC' in str(query)
 
-    def test_sort_by_joined_table_column(self):
+    def test_joined_table_column(self):
         query = self.session.query(self.Article).join(self.Article.category)
         sorted_query = sort_query(query, 'category-name')
         assert 'category.name ASC' in str(sorted_query)
 
-    def test_sort_by_multiple_columns(self):
+    def test_multiple_columns(self):
         query = self.session.query(self.Article)
         sorted_query = sort_query(query, 'name', 'id')
         assert 'article.name ASC, article.id ASC' in str(sorted_query)
 
-    def test_sort_by_column_property(self):
+    def test_column_property(self):
         self.Category.article_count = sa.orm.column_property(
             sa.select([sa.func.count(self.Article.id)])
             .where(self.Article.category_id == self.Category.id)
@@ -83,7 +83,7 @@ class TestSortQuery(TestCase):
         sorted_query = sort_query(query, 'article_count')
         assert 'article_count ASC' in str(sorted_query)
 
-    def test_sort_by_column_property_descending(self):
+    def test_column_property_descending(self):
         self.Category.article_count = sa.orm.column_property(
             sa.select([sa.func.count(self.Article.id)])
             .where(self.Article.category_id == self.Category.id)
@@ -94,15 +94,40 @@ class TestSortQuery(TestCase):
         sorted_query = sort_query(query, '-article_count')
         assert 'article_count DESC' in str(sorted_query)
 
-    def test_sort_by_hybrid_property(self):
+    def test_hybrid_property(self):
         query = self.session.query(self.Category)
         query = sort_query(query, 'articles_count')
         assert 'ORDER BY (SELECT count(article.id) AS count_1' in str(query)
 
-    def test_sort_by_hybrid_property_descending(self):
+    def test_hybrid_property_descending(self):
         query = self.session.query(self.Category)
         query = sort_query(query, '-articles_count')
         assert (
             'ORDER BY (SELECT count(article.id) AS count_1'
         ) in str(query)
         assert ' DESC' in str(query)
+
+    def test_relation_hybrid_property(self):
+        query = (
+            self.session.query(self.Article)
+            .join(self.Article.category)
+            .correlate(self.Article.__table__)
+        )
+        query = sort_query(query, '-category-articles_count')
+        assert 'ORDER BY (SELECT count(article.id) AS count_1' in str(query)
+
+    def test_aliased_relation_hybrid_property(self):
+        alias = sa.orm.aliased(
+            self.Category,
+            name='category'
+        )
+        query = (
+            self.session.query(self.Article)
+            .outerjoin(alias, self.Article.category)
+            .options(
+                sa.orm.contains_eager(self.Article.category, alias=alias)
+            )
+        )
+        query = sort_query(query, '-category-articles_count')
+        print query
+        #assert 'ORDER BY (SELECT count(article.id) AS count_1' in str(query)
